==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/LineBisector/ts/LineBisector_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineBisector</name>
    <message>
        <location filename="../LineBisector.js" line="+66"/>
        <source>First line</source>
        <translatorcomment>--google--
Zaznacz pierwszą linię
Zaznacz pierwszą linię lub łuk
Wskaż pierwszą linie</translatorcomment>
        <translation type="unfinished">Pierwsza linia</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Second line</source>
        <translatorcomment>--google--
Zaznacz drugą linię
Wskaż drugą linię [długość/liczba]
Wskaż drugą linie</translatorcomment>
        <translation type="unfinished">Druga linia</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Lines don&apos;t intersect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Linie nie przecinają się.</translation>
    </message>
    <message>
        <location filename="../LineBisector.ui" line="+17"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation type="unfinished">Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation type="unfinished">Liczba:</translation>
    </message>
    <message>
        <location filename="../LineBisectorInit.js" line="+2"/>
        <source>Angle &amp;Bisector</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kąt Dwusieczna</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw angle bisector, trisector, ...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj kąt bisector, trisector ...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/LineBisector/ts/LineBisector_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineBisector</name>
    <message>
        <location filename="../LineBisector.js" line="+66"/>
        <source>First line</source>
        <translatorcomment>--google--
Zaznacz pierwszą linię
Zaznacz pierwszą linię lub łuk
Wskaż pierwszą linie</translatorcomment>
        <translation>Pierwsza linia</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Second line</source>
        <translatorcomment>--google--
Zaznacz drugą linię
Wskaż drugą linię [długość/liczba]
Wskaż drugą linie</translatorcomment>
        <translation>Druga linia</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Lines don&apos;t intersect.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linie nie przecinają się.</translation>
    </message>
    <message>
        <location filename="../LineBisector.ui" line="+17"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation>Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation>Ilość:</translation>
    </message>
    <message>
        <location filename="../LineBisectorInit.js" line="+2"/>
        <source>Angle &amp;Bisector</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Dwusieczna kąta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw angle bisector, trisector, ...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje dwusieczną, trzysieczną kąta,..</translation>
    </message>
</context>
</TS>
